@@ -6,6 +6,6 @@
 # All rights reserved.
 # -------------------------------
 
-from .juniper_source import *
+#from .juniper_source import *
 #from .ply.lex import *
 #from .ply.yacc import *
\ No newline at end of file
