@@ -8,8 +8,8 @@
 
 # Packages
 
-from ply import lex as lex
-from ply import yacc as yacc
+import junipercs.ply.lex as lex
+import junipercs.ply.yacc as yacc
 import sys 
 import os # delete
 
@@ -21,10 +21,10 @@ from system_parser.tokens_definition import *
 
 # Commands
 
-from modules import options as options
-from modules import create as create
-from modules import goto as goto
-from modules import list as list_cmd
+import modules.options as options
+import modules.create as create
+import modules.goto as goto
+import modules.list as list_cmd
 
 #-------------------------------------------
 # ___________GLOBAL VARIABLES_______________
